@@ -123,7 +123,7 @@ class Node
     elsif @path =~ ABSOLUTE_URL
       @path
     else
-      full_path.sub( /^#{Node.root( self ).path}/, '/' )
+      full_path.sub( /^#{Regexp.escape(Node.root( self ).path)}/, '/' )
     end
   end
 
@@ -151,11 +151,11 @@ class Node
   # matched portion or +nil+. Used by #resolve_node.
   def =~( path )
     md = if is_directory?
-           /^#{@path.chomp('/')}(\/|$)/ =~ path                  #' #emacs hack
+           /^#{Regexp.escape(@path.chomp('/'))}(\/|$)/ =~ path                  #' #emacs hack
          elsif is_fragment?
-           /^#{@path}$/ =~ path
+           /^#{Regexp.escape(@path)}$/ =~ path
          else
-           /^#{@path}(?=#|$)/ =~ path
+           /^#{Regexp.escape(@path)}(?=#|$)/ =~ path
          end
     if md then $& end
   end
