@@ -220,9 +220,9 @@ module CorePlugins
     end
 
     def define_webgen_emoticons
-      Dir[File.join( Webgen.data_dir, 'resources', 'emoticons', '*/')].each do |pack_dir|
+      Dir.glob(File.join( Webgen.data_dir, 'resources', 'emoticons', '*/'), File::FNM_CASEFOLD ).each do |pack_dir|
         pack = File.basename( pack_dir )
-        Dir[File.join( pack_dir, '*' )].each do |smiley_file|
+        Dir.glob( File.join( pack_dir, '*' ), File::FNM_CASEFOLD ).each do |smiley_file|
           smiley = File.basename( smiley_file, '.*' )
           res = define_file_resource( "webgen-emoticons-#{pack}-#{smiley}",
                                       smiley_file,
@@ -234,7 +234,7 @@ module CorePlugins
 
     def define_webgen_icons
       base_dir = File.join( Webgen.data_dir, 'resources', 'icons' )
-      Dir[File.join( base_dir, '**/*')].each do |icon|
+      Dir.glob( File.join( base_dir, '**/*'), File::FNM_CASEFOLD ).each do |icon|
         dirs = File.dirname( icon ).sub( /^#{base_dir}/, '' ).split( '/' ).join( '-' )
         dirs += '-' if dirs.length > 0
         res = define_file_resource( "webgen-icons-#{dirs}#{File.basename( icon, '.*' )}",
