@@ -225,7 +225,7 @@ module FileHandlers
         log(:info) { "Not using these files for #{handler.class.plugin_name} as they do not exist or are excluded: #{diff.inspect}" } if diff.length > 0
         common.each  do |file|
           log(:info) { "Creating node(s) for file <#{file}>..." }
-          create_node( file.sub( /^#{root_node.node_info[:src]}/, '' ), root_node, handler )
+          create_node( file.sub( /^#{Regexp.escape(root_node.node_info[:src])}/, '' ), root_node, handler )
         end
       end
 
@@ -283,7 +283,7 @@ module FileHandlers
 
     # Returns an array of files of the source directory matching +pattern+
     def files_for_pattern( pattern )
-      files = Dir[File.join( param( 'srcDir', 'Core/Configuration' ), pattern )].to_set
+      files = Dir.glob( File.join( param( 'srcDir', 'Core/Configuration' ), pattern ), File::FNM_CASEFOLD ).to_set
       files.delete( File.join( param( 'srcDir', 'Core/Configuration' ), '/' ) )
       files.collect!  do |f|
         f = f.sub( /([^.])\.{1,2}$/, '\1' ) # remove '.' and '..' from end of paths
@@ -411,12 +411,25 @@ module FileHandlers
     def link_from( node, ref_node, attr = {} )
       attr = node['linkAttrs'].merge( attr ) if node['linkAttrs'].kind_of?( Hash )
       link_text = attr[:link_text] || node['title']
+      context = attr[:context]
       attr.delete_if {|k,v| k.kind_of?( Symbol )}
 
       use_link = ( node != ref_node || param( 'linkToCurrentPage' ) )
       attr['href'] = ref_node.route_to( node ) if use_link
       attrs = attr.collect {|name,value| "#{name.to_s}=\"#{value}\"" }.sort.unshift( '' ).join( ' ' )
-      ( use_link ? "<a#{attrs}>#{link_text}</a>" : "<span#{attrs}>#{link_text}</span>" )
+      if !node['link_callback'].nil?
+        result = begin
+                   instance_eval(node['link_callback'])
+                 rescue
+                   log(:error) { "Error while evaluating link callback from node <#{node.node_info[:src]}>: #{$!.message}" }
+                   nil
+                 end
+      end
+      if result.nil?
+        ( use_link ? "<a#{attrs}>#{link_text}</a>" : "<span#{attrs}>#{link_text}</span>" )
+      else
+        result
+      end
     end
 
   end
