@@ -237,7 +237,7 @@ module FileHandlers
       end
 
       @path = File.dirname( file )
-      images = Dir[File.join( @path, param( 'images' ))].collect {|i| i.sub( /#{@path + File::SEPARATOR}/, '' ) }
+      images = Dir.glob( File.join( @path, param( 'images' )), File::FNM_CASEFOLD ).collect {|i| i.sub( /#{Regexp.escape(@path + File::SEPARATOR)}/, '' ) }
       images.sort! do |a,b|
         aoi = @imagedata[a].nil? ? 0 : @imagedata[a]['orderInfo'].to_s.to_i || 0
         boi = @imagedata[b].nil? ? 0 : @imagedata[b]['orderInfo'].to_s.to_i || 0
@@ -376,7 +376,7 @@ module FileHandlers
       if @plugin_manager.optional_part( 'gallery-exif' )[:loaded]
         jpeg = EXIFR::JPEG.new( image ) rescue nil
         if !jpeg.nil? && jpeg.exif?
-          exif = jpeg.exif.dup
+          exif = jpeg.exif.to_hash
           exif[:width] = jpeg.width
           exif[:height] = jpeg.height
           exif[:comment] = jpeg.comment
@@ -434,13 +434,17 @@ module FileHandlers
         ':cropped (resized to exact thumbnail size, image parts maybe cropped)'
 
       def create_node( file, parent, meta_info, thumbnailSize = nil, method = nil )
-        node = Node.new( parent, 'tn_' + File.basename( file ).tr( ' ', '_' ) )
-        node.meta_info.update( meta_info )
-        node['title'] = node.path
-        node.node_info[:thumbnail_size] = thumbnailSize || param( 'thumbnailSize' )
-        node.node_info[:thumbnail_file] = file
-        node.node_info[:thumbnail_resize_method] = method || param( 'resizeMethod' )
-        node.node_info[:processor] = self
+        name = 'tn_' + File.basename( file ).tr( ' ', '_' )
+        if !(node = parent.find {|c| c =~ name })
+          node = Node.new( parent, name )
+          node.meta_info.update( meta_info )
+          node['title'] = node.path
+          node.node_info[:thumbnail_size] = thumbnailSize || param( 'thumbnailSize' )
+          node.node_info[:thumbnail_file] = file
+          node.node_info[:thumbnail_resize_method] = method || param( 'resizeMethod' )
+          node.node_info[:processor] = self
+        end
+
         node
       end
 
